Auto Refresh

| {$ 'TimeStamp' | translate $} | {$ 'Name' | translate $} | {$ 'Resource Type' | translate $} | {$ 'Resource ID' | translate $} | {$ 'Severity' | translate $} | {$ 'Type' | translate $} | {$ 'RCA' | translate $}
--- | --- | --- | --- | --- | --- | --- | ---
| {$alarm.update_timestamp | date:"yyyy-MM-dd hh:mm:ss"$} | {$alarm.name$} | {$alarm.resource_type$} | {$alarm.resource_id$} | {$alarm.normalized_severity | lowercase$} | {$alarm.type$} |